"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildTsInterfaceString = exports.getQueriesArgsTSInterfaces = exports.getObjectTSInterfaces = exports.generateQGLArg = exports.generatedTsFields = exports.getOneTSTypeDisplay = exports.generateUnionType = exports.generateEnumType = void 0;
var utilities_1 = require("../utilities");
var parameters_store_1 = require("../store/parameters.store");
exports.generateEnumType = function (object) {
    var prefix = parameters_store_1.ParametersStore.prefix, suffix = parameters_store_1.ParametersStore.suffix;
    var ObjectName = object.name;
    var generatedFields = object.enumValues.map(function (field) { return field.name; });
    return (object.description ? "/** " + object.description + " */\n" : '') + " export enum " + (prefix ? prefix : '') + ObjectName + (suffix ? suffix : '') + " {\n        " + generatedFields
        .map(function (enumType) { return utilities_1.capitalizeAllWord(enumType) + " = \"" + enumType + "\""; })
        .join(',\n') + "\n  }";
};
exports.generateUnionType = function (object) {
    var _a;
    var prefix = parameters_store_1.ParametersStore.prefix, suffix = parameters_store_1.ParametersStore.suffix;
    var ObjectName = object.name;
    return (object.description ? "/** " + object.description + " */\n" : '') + " export type " + (prefix ? prefix : '') + ObjectName + (suffix ? suffix : '') + " = " + ((_a = object.possibleTypes) === null || _a === void 0 ? void 0 : _a.map(function (type) { return type.name; }).join('|'));
};
exports.getOneTSTypeDisplay = function (_a) {
    var field = _a.field;
    var prefix = parameters_store_1.ParametersStore.prefix, suffix = parameters_store_1.ParametersStore.suffix, listScalars = parameters_store_1.ParametersStore.listScalars;
    var _b = utilities_1.evaluateType(field), isScalar = _b.isScalar, typeName = _b.typeName, isArray = _b.isArray;
    var returnedName = isScalar
        ? listScalars[typeName]
        : "" + (prefix ? prefix : '') + typeName + (suffix ? suffix : '');
    return returnedName + (isArray ? '[]' : '');
};
exports.generatedTsFields = function (fields, isInput) {
    return fields.map(function (field) {
        var propertyName = field.name;
        var isRequired = utilities_1.evaluateType(field).isRequired;
        var TStypeName = exports.getOneTSTypeDisplay({ field: field });
        return (field.description ? "/** " + field.description + "*/\n" : '') + " " + propertyName + (isRequired ? '' : isInput ? '?' : '') + ": " + (isRequired || isInput ? TStypeName : "Maybe<" + TStypeName + ">") + ";";
    });
};
exports.generateQGLArg = function (field) {
    var _a = utilities_1.evaluateType(field), isArray = _a.isArray, isArrayRequired = _a.isArrayRequired, isRequired = _a.isRequired, typeName = _a.typeName;
    return "" + (isArray ? '[' : '') + typeName + (isArrayRequired ? '!' : '') + (isArray ? ']' : '') + (isRequired ? '!' : '');
};
exports.getObjectTSInterfaces = function (object, isInput) {
    var fieldsKey = isInput ? 'inputFields' : 'fields';
    var generatedFields = exports.generatedTsFields(object[fieldsKey], isInput);
    return exports.buildTsInterfaceString(object, generatedFields);
};
exports.getQueriesArgsTSInterfaces = function (object) {
    var generatedFields = exports.generatedTsFields(object.args, true);
    return exports.buildTsInterfaceString(object, generatedFields, 'Args');
};
exports.buildTsInterfaceString = function (type, fields, additionalSuffix) {
    var prefix = parameters_store_1.ParametersStore.prefix, suffix = parameters_store_1.ParametersStore.suffix;
    return (type.description ? "/** " + type.description + " */\n" : '') + " export interface " + (prefix ? prefix : '') + type.name + (suffix ? suffix : '') + (additionalSuffix ? additionalSuffix : '') + " {\n    " + fields.join('\n') + "\n  }\n";
};
